package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@(!`0````````````(`"``!````<!T`(`$```!``````````/"W````
M````!P"B@$``.``*`$``'@`=``8````%````0`````````!````@`0```$``
M`"`!````,`(````````P`@````````@``````````P````0```!PI@``````
M`'"F`"`!````<*8`(`$````/``````````\``````````0`````````#``!P
M!````'`"````````<`(`(`$```!P`@`@`0```!@`````````&``````````(
M``````````$````%```````````````````@`0```````"`!````I*8`````
M``"DI@```````````0```````0````8```#HKP```````.BO`2`!````Z*\!
M(`$```"(`P```````,@3```````````!```````"````!````$`$````````
M0`0`(`$```!`!``@`0```#`"````````,`(````````(``````````0````$
M````&`0````````8!``@`0```!@$`"`!````)``````````D``````````0`
M````````!`````0```"$I@```````(2F`"`!````A*8`(`$````@````````
M`"``````````!`````````!2Y71D!````.BO````````Z*\!(`$```#HKP$@
M`0```!@`````````&``````````!````````````````````````````````
M``````````````````````````````````````````@```````````!``@("
M``$$``````````$``````````2@```````#V!P"R````````````````````
M```````P,`(@`0````$H````````````````````````````````````````
M,#`"(`$````!*````````````````````````````````````````#`P`B`!
M`````2@````````$``"R```````````````````````````P,`(@`0````$H
M````````/``!L@``````````````````````````,#`"(`$````!*```````
M`/S___,```````````,``````````````#`P`B`!`````2@```````"$``"R
M```````````````````````````P,`(@`0````$H````````<``_L@``````
M````````````````````,#`"(`$````!*```````````````````````````
M`````````````#`P`B`!`````2@```````````"P````````````````````
M```````P,`(@`0````0````4`````P```$=.50#Y;_F$IB'2#]LQ\^;($)J_
MJG412@`````!`````````!\$`````````0````````!*!`````````$`````
M````;`0````````!`````````(\$````````#`````````"@&@`@`0````T`
M````````$&0`(`$````9`````````.BO`2`!````&P`````````(````````
M`!H`````````\*\!(`$````<``````````@`````````!`````````!P!@`@
M`0````4`````````Z!,`(`$````&`````````+`)`"`!````"@`````````L
M!0````````L`````````&``````````6``!P`````#"P`2`!````-0``<```
M``#PJ@$``````!4````````````````````#`````````$"P`2`!`````0``
M<``````!``````````4``'```````@`````````&``!P`````````"`!````
M"@``<``````<`````````!$``'``````;0`````````2``!P`````!T`````
M````$P``<``````D`````````/[__V\`````\!D`(`$```#___]O``````,`
M````````\/__;P`````4&0`@`0``````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````&$```!M````````````````
M````+```````````````-``````````_````*0```$\`````````20```%``
M```-`````````%D````9`````@```"X````(````$````$`````Q````````
M``````!:````%````"@``````````````",````<````00```#(`````````
M%@```"(`````````.``````````V`````````&H````5````$0```"8`````
M`````````!H```!7````2````%8``````````````!@```!*````/````$<`
M`````````````&(`````````4P`````````A``````````````!E````)P``
M`"H````O````1@```"L```````````````$````*````0P```&@````;````
M#P```#<`````````)````!\``````````````!(````7`````````$(````>
M````1````"4````S````/0```````````````````"```````````````&<`
M``````````````````!I````````````````````4@```&8````)````#```
M````````````10```!,````#`````````````````````````&````!<````
M``````````````````````````!?````.0```#X`````````-0```$P````P
M````'0`````````M``````````````!A````;`````````!1`````````#L`
M````````2P`````````Z````5```````````````9````$X`````````````
M````````````#@`````````'`````````&,````+````30``````````````
M70``````````````6P````````````````````````!5````6```````````
M``````````````````````````````!>````:P``````````````!```````
M``````````````8`````````````````````````!0``````````````````
M```````````````````````````````````````1````$@`+`"A@`"`!````
M"`````````##!```$@`+`'A!`"`!````&``````````O!```$P#Q_P$`````
M``````````````#C!```(0`5``"P`2`!``````````````"%!```$0``````
M```````````````````@`@``$@`+`.!(`"`!````4``````````.!```$@`+
M`&A>`"`!````M`````````"E!```$``8`'"S`2`!```````````````;````
M$@`-`!!D`"`!``````````````#4!```$@`+`!A$`"`!````+`````````!"
M`P``$@`+`$A$`"`!````:`$````````-`P``$@`+``A+`"`!````,`X`````
M``#A!```$0`5``"P`2`!``````````````!V!```$0`.`$!D`"`!````!```
M``````">!```$``5``"P`2`!``````````````#0`0``$@`+`'A``"`!````
M_`````````!`!```$0`6`#"P`2`!```````````````!````$@`+`(!?`"`!
M````J`````````"[`P``$0`5`""P`2`!````"`````````"^!```$``9`+##
M`2`!``````````````!P`P``$@(+`"!?`"`!````7`````````#"`@``$@`+
M`+!%`"`!````A`(```````"L!```$``9`'"S`2`!``````````````"3`0``
M$@`+`+`_`"`!````4``````````N````$@`+`.`:`"`!````B`(```````#N
M!```$@`+`'`=`"`!``````````````!G`@``$@`+`)!!`"`!````B`(`````
M``")`@``$@`+`#!)`"`!````U`$```````"&!```(0``````````````````
M``````!T`@``$@`+`#A(`"`!````I`````````"7!```$``+`.`:`"`!````
M``````````!"`````0`6`#BP`2`!``````````````"X!```$``9`'"S`2`!
M``````````````"5`0``$@`*`*`:`"`!``````````````"L`0``$@`+`#A9
M`"`!````,`4```````#U````$@```/!C`"`!``````````````#:````$@``
M`.!C`"`!``````````````#L````$@```-!C`"`!``````````````"U`@``
M$@```,!C`"`!```````````````Y`0``$@```+!C`"`!```````````````E
M`0``$@```*!C`"`!```````````````#`0``$@```)!C`"`!````````````
M``"'!```$0````````````````````````"[````$@```(!C`"`!````````
M``````!J````(`````````````````````````!9`@``$@```'!C`"`!````
M``````````#B````$@```&!C`"`!```````````````%!```$@```%!C`"`!
M``````````````!;`0``$@```$!C`"`!``````````````"$````(```````
M``````````````````!_`P``$@````````````````````````#?`@``$@``
M`#!C`"`!``````````````#M`0``$@```"!C`"`!``````````````!$`0``
M$@```!!C`"`!``````````````";`0``$@````!C`"`!``````````````#%
M`P``$@```/!B`"`!```````````````$`@``$@```.!B`"`!````````````
M```V`P``$@```-!B`"`!``````````````#H`P``$@```,!B`"`!````````
M``````!4`0``$@```+!B`"`!``````````````!!`@``$@```*!B`"`!````
M``````````!=`P``$@````````````````````````#[`0``$@```)!B`"`!
M```````````````[`@``$@```(!B`"`!``````````````"[`@``$@```'!B
M`"`!``````````````!X`0``$@```&!B`"`!```````````````A`P``$@``
M`%!B`"`!``````````````""`@``$@```$!B`"`!```````````````A````
M$@```#!B`"`!``````````````##````$@```"!B`"`!``````````````!.
M`P``$@```!!B`"`!``````````````#F`0``$@````!B`"`!````````````
M```:!```$@```/!A`"`!```````````````S````(@``````````````````
M``````"H`@``$@```.!A`"`!``````````````#/`@``$@```-!A`"`!````
M``````````"T`P``$@```,!A`"`!``````````````#*````$@```+!A`"`!
M``````````````"H`P``$@```*!A`"`!``````````````#"`0``$@```)!A
M`"`!``````````````";`@``$@```(!A`"`!``````````````!:!```$@``
M`'!A`"`!``````````````"=`P``$@```&!A`"`!``````````````#M`@``
M$@```%!A`"`!``````````````!J`0``$@```$!A`"`!``````````````!+
M`0``$@```#!A`"`!```````````````:`P``$@```"!A`"`!````````````
M``"0`P``$0````````````````````````#0`P``$@```!!A`"`!````````
M```````-`0``$@````!A`"`!```````````````:`0``$0``````````````
M```````````2`@``$@```/!@`"`!``````````````"J````$@```.!@`"`!
M``````````````#>`P``$@```-!@`"`!``````````````#V`P``$@```,!@
M`"`!```````````````4`0``$@```+!@`"`!``````````````"#`0``$@``
M``````````````````````#_`@``$@```*!@`"`!``````````````"8````
M$0````````````````````````#)`0``$@```)!@`"`!``````````````#C
M`P``$@```(!@`"`!``````````````#2````$@```'!@`"`!````````````
M``!2`@``$0`````````````````````````R`@``$@```&!@`"`!````````
M``````!.````(`````````````````````````"C`@``$@```%!@`"`!````
M``````````#T`0``$@```$!@`"`!```````````````9`@``$@```#!@`"`!
M````````````````7U]L:6)C7V-S=5]I;FET`%]?;&EB8U]C<W5?9FEN:0!?
M7VQI8F-?<W1A<G1?;6%I;@!?7V=M;VY?<W1A<G1?7P!?7U1-0U]%3D1?7P!?
M251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]R96=I<W1E<E1-0VQO
M;F5486)L90!?2G9?4F5G:7-T97)#;&%S<V5S`%]?<W1A8VM?8VAK7V=U87)D
M`%]?<W1A8VM?8VAK7V9A:6P`<W1R;F-M<`!S=')L96X`<F5A;&QO8P!M96UM
M;W9E`&]P96YD:7(`<F5A9&1I<C8T`&-L;W-E9&ER`%]?<W!R:6YT9E]C:&L`
M7U]X<W1A=#8T`'5N;&EN:P!R;61I<@!03%]T:')?:V5Y`'!T:')E861?9V5T
M<W!E8VEF:6,`7U]L>'-T870V-`!A8V-E<W,`<F5A9&QI;FL`;65M8VAR`%!E
M<FQ?<W9?<V5T<'9N`%!E<FQ?<W9?<V5T<'8`4&5R;%]N97=84P!B;V]T7T1Y
M;F%,;V%D97(`>'-?:6YI=`!097)L7VYE=UA37V9L86=S`%A37TEN=&5R;F%L
M<U]005)?0D]/5`!G971P:60`;65M8W!Y`'!A<E]C=7)R96YT7V5X96-?<')O
M8P!S=')C:'(`<W1R=&]K`'-T<F-M<`!?7W-T<F1U<`!?7W-T<FYC<'E?8VAK
M`&=E='5I9`!S=')S='(`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`;6MD
M:7(`7U]E<G)N;U]L;V-A=&EO;@!S=&1E<G(`7U]F<')I;G1F7V-H:P!P87)?
M9FEN9'!R;V<`<&%R7V5N=E]C;&5A;@!O<&5N-C0`<&%R7W-E='5P7VQI8G!A
M=&@`;'-E96LV-`!R96%D`%]?;65M8W!Y7V-H:P!C;&]S90!M96US970`<&%R
M7VEN:71?96YV`%!E<FQ?9W9?9F5T8VAP=@!097)L7V%V7V9E=&-H`%!E<FQ?
M<W9?,G!V7V9L86=S`%!E<FQ?879?<VAI9G0`<&%R7VUK=&UP9&ER`&5X96-V
M<`!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!P87)?9&ER;F%M
M90!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO8VL`<'1H<F5A9%]A
M=&9O<FL`4&5R;%]A=&9O<FM?;&]C:P!03%]D;U]U;F1U;7``<&5R;%]A;&QO
M8P!097)L7W-A9F5S>7-M86QL;V,`;7E?<&%R7W!L`'!E<FQ?<&%R<V4`<&5R
M;%]D97-T<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P97)L7V-O;G-T
M<G5C=`!P97)L7W)U;@!P87)?8VQE86YU<`!E>&ET`&QI8G!E<FPN<V\N-2XR
M,@!?1%E.04U)0U],24Y+24Y'`%]?4DQ$7TU!4`!L:6)P=&AR96%D+G-O+C``
M7U]R96=I<W1E<E]A=&9O<FL`;&EB8RYS;RXV`%])3U]S=&1I;E]U<V5D`%]?
M96YV:7)O;@!L9"YS;RXQ`%]F=&5X=`!?9F1A=&$`7V5D871A`%]?8G-S7W-T
M87)T`%]F8G-S`%]E;F0`<&%R7V-U<G)E;G1?97AE8P!P87)?8F%S96YA;64`
M7U]D871A7W-T87)T`%]?<W1A<G0`1TQ)0D-?,BXT`$=,24)#7S(N,@!'3$E"
M0U\R+C``1TQ)0D-?,BXS+C0`1TQ)0D-?,BXS+C(````!``$``0`!``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``(`
M`0`!``$``0`!``$`"``"``(``P`)``,`"0`"``(````(``D`````````````
M``(``@``````"````````@`#`````@`"``(```````<``@`"`````@`"````
M"`````(``@````(`!P`&``````````(``@```````@````(`!0```````@``
M````!``"``(``@`"``(````#``(``@````$``0"/!```$````"`````4:6D-
M```$`/8$`````````0`"`$H$```0````,````!)I:0T```<```4``!`````0
M:6D-```#``H%`````````0`%`&P$```0`````````!)I:0T```D```4``!``
M``!T&6D)```(`!0%```0````<AEI"0``!@`@!0``$````!1I:0T```4`]@0`
M`!`````0:6D-```"``H%````````\/^]9P``O/\"`!P\+>"9`P@`O_^0%9QG
M((*"WP0`0!``````((*9WPGX(`,`````"`"_WP``O-\(`.`#$`"]9Y#_O6>_
M`;SK`@`</!``I?\0`*5G+>"9`P@`IO\(`*9G4!6<9QP`I*\<`*1G\0"PZ^B"
MD=]U`;3K,P&RZPB"F=\``"+>*`"B_PGX(`,`````P(&&WZB`F=]H@83?^!`1
M!"4HP`"0@H+?``!"D%X`0!!H@IG?.("0WZB"DM\8@9G?"?@@`P``1(X``$2.
MN@5#D!B!F=\"`&,T"?@@`[H%0Z`<`*2/N@5#D$B"F=\%`(0D`0!C-/@@!``)
M^"`#N@5#H!``I=^P@(3?'`"FCP``H]P``(?<.("(WP(`Q"@$`,DD``!#_$B`
M@]\0`$?\!``')(C#`OU@:&-D"`!#_$B`@]]H:&-D&`!#_#B`@]\+`(`4D,-G
MK`@`I60%``,D)4`@`0``I]SX(`,``0!C)"T@1``(`*5D^O]H%/C_A_Q(@(7?
M^$@)`"4X0`"0@9G?+1!)`"5```"@PP3>`P#&)`!`I60)^"`#^/]`_"P`0!`E
MF$``F(*9WR0`M&>@PP3>"?@@`TB`DM](@(3?)2B``D@W4F8ER$`"M`81!#!E
MA&0D`$`0.("5W\""F=\)^"`#H,,$WJB!F=\)^"`#`````"@`I-\E$&`"```C
MWBT`@Q2X@IG?OP&\RW4!M,LS`;++\0"PRP@`X`-P`+UG"?@@`SB`D-\@`$`0
MH,,"_LB"F=\E($``"?@@`ZB"DM\8@9G?"?@@`P``1(Z9_P`0O0E`H%"!F=\)
M^"`#H,,$WM'_`!`EF$``F,.DW@4`@!"X@)G?4A`1!`````#8_P`0P(*9WTB`
MA-\E*(`")<A``H,&$02X9(1D)2!``,__0!"8PZ+^\_\`$+B`F=\8@IG?"?@@
M`P$`!"0)^"`#````````````````)0#@`P$`$00`````)<B``P(`'#RT$IPG
M+>"?`R7X```@@(3?``"EWP@`IF?P_P$D).BA`RB`A]\P@(C?)4A``"50H`/X
M@9G?"?@@`P````#__P`0`````````````````@`#/"T8>0!@$F-D.(!DW$"`
M8MPXL(1D!P!"9"\01``/`$(L!0!`%!B#>=P#`"`3``````@`(`,`````"`#@
M`P```````````@`#/"T8>0`8$F-D.(!DW$"`8MPXL(1D+Q!$`/L0`@#^+P(`
M+2BB`'LH!0`%`*`0.(%YW`,`(!,`````"``@`P`````(`.`#``````````#@
M_[UG?P"\ZP(`'#P(`+#_+>"9`\@1G&<X@)#?<+,"D@8`0!1(@)G?T!TY9\[_
M$00``````0`")'"S`J)_`+S+"`"PWP@`X`,@`+UG`````/#_O6<_`+SK`@`<
M/"W@F0-X$9QG.(""W_BO1&0``(+<!P!`%&"!F=](@)G?/P"\RQ@>.6?*_P`0
M$`"]9P````#Y_R`3``````GX(`,`````]O\`$$B`F=\P_;UG.`"*9#\+O.L"
M`!P\"`"K9RW@F0-X`(UD(!&<9_\`##SH@HG?]0JTZ[,*LNMQ"K#K```BW8@"
MHO\```````!'W0@`2F40`&ME/D`'`/C_1HT^%@<`."X(`#@:"``#^*5\)!AL
M`*`P!GPE&*,`/CH'`"488@`"-"8``/_B,`/XQGPE$&(`\/]F_>S_317X_V+]
M<`"E9W`"J&<```````"CW`@`I630_Z?<H/^BW)#_IMPF&&<`)A!B`"801@!X
M&`(`^A<"`"408@`#^$)\\_^H%!``HOP``(S<@EH#/-EN`CP0`(C<F7EC9*'K
M0C08`(K<(`"+W/HV#`!X*0P`"`"MWR4HI@"Z<`P`"`"'W"8P"@&XAPP``_BE
M?"6`#@(0`+C?+6AM`0/X$'X@`+3?+6BC`20PQP"X=P<`+2BM`+J(!P`F,,H`
M+3"F`"6(T0$#^,U\`_@Q?@`(L40F*!$!^LX-````K40MP%@!>'$-`"0HK``M
MP`,#)7#9`28HJ``8`+G?+2BX``/XSGT"`.%++2BN```(L$0DF-```_BX?"W(
M&0%X<1@`^C88`"W((P,E,,8!`_C&?"V@@P(MB)$"*`"TWP``+T0``+A$+:"#
M`BV`D`(E>/,!`@#A2RUP^0&X?PT`NF@-`"UPQ@$E:.T!`_C9?0/XKWUX,1D`
M``BO1"1HKP#Z+AD`)2C%`+HP&````#)$`_BE?```N40E:$T"`@#A2RUHL0&X
MCQ@`+6BE`27`)@(#^!A_`_BF?0`(N$0DB-@!>"D&`/IV!@`E<*X`NB@9````
M,T0#^,Y]``"F1"6(<0(P`+/?`@#A2RV`,`*XCQD`+7`.`B7()0(#^#E_`_C%
M?0`(N40DH+D!+9AC`GB!!0#Z;@4`+7AO`B5H#0(X`+/?```R1+B'!@`#^*U]
M``"E1+HP!@`MF&,"+<!X`D``L]\ED%0"`@#A2RUX3P(M:.T!)7@&`@/X[WT#
M^*9]``BO1"2@SP%X@08`^G8&`"V88P(E<`X"N(<%````,42Z*`4``_C.?0``
MID0MR'D"2`"SWR6(-`("`.%++<`X`BV88P(M<`X#)<`%`@/X&'\#^,5]``BX
M1"2@N`%X@04`^FX%`"UX;P)0`+/?)6@-`KB'!@```#)$NC`&``/XK7T``*5$
M)8`&`BV88P(#^!!^+<!X`B605`(DH-`!`@#A2RW(60(`"+!$+6@M`P/XIGUX
MR08`^G8&`"5P+@.XSP4``_C.?;HH!0```#%$)<@E`P``ID0#^#E_)8@T`B2@
MN0$"`.%++7@O`@`(N40M>.X!`_CE?7AQ!0#Z;@4`)6C-`0/XK7T``#)$``"E
M1"605`("`.%++7!8`KC'!@!8`++?NC`&`"UPS0$E,`8#`_C-?0/XV'PMD$,"
M``BX1/JF#0`D>/@!>#$-`"V`4`(``#%$)3#4````K40#^,9\8`"TWR5X+P("
M`.%++7CP`;B'!0"Z*`4`+7CF`8@"IM\E@`4"`_CE?0/X$'XMH(,"``BP1"1P
MT`%XB04`^JX%`"W(F0)H`+3?```S1```I40MH(,"+<"8`G``M-\EF&X")7`U
M`@(`X4LMR'D"N(\-``/XSGVZ:`T`+7`N`R7(+0(#^#E_`_C-?0`(N40D>/D!
M>(D-`/JN#0`MH(,"```R1"V`D`(``*U$>`"TWR603P(E>#4"`@#A2RW`6`*X
MCP4``_CO?;HH!0`M>`\#)<`E`@/X&'\#^.5]``BX1"1PV`%XB04`^JX%`"V@
M@P(``#-$+<B9`@``I42``+3?)9AN`B5P-0("`.%++8!P`KB/#0`#^,Y]NF@-
M`"UP#@(E@"T"`_@0?@/XS7T`"+!$)'CP`7B)#0#ZK@T`+:"#`@``,D0MP)@"
M``"M1(@`M-\ED$\")7@U`@(`X4LMR%D"N(\%``/X[WVZ*`4`+7@O`R7()0(#
M^#E_`_CE?0`(N40D<-D!>(D%`/JN!0`MH(,"```S1"V`D`(``*5$D`"TWR68
M;@(E<#4"`@#A2RW`>`*XCPT``_C.?;IH#0`M<`X#)<`M`@/X&'\#^,U]``BX
M1"1X^`%XB0T`^JX-`"V@@P(``#)$+<B9`@``K428`+3?)9!/`B5X-0("`.%+
M+8!0`@/X[WVXEP4`NB@%`"UX#P(ED$4"`_A2?@/XY7T`"+)$)'#2`7B!!0#Z
MK@4`+:"#`@``,T0MP)@"``"E1"68;@(E<!4"`@#A2RW(>0*XAPT``_C.?;IH
M#0`M<"X#)6@-`@/XV7T#^+!]``BP1"1X\`%X:1D`^JX9````,40E:+4!``"Y
M1`/XK7TE>"\"`@#A2RW`^`&X?P4`+<`-`[HH!0"@`*W?)2CE`0/X$7\#^*]\
M^J81`"T8HP$D<,\!>&D1`"V0<@```#-$)1BT`;IH&0`#^&-\)7!N`BUPT@&X
MEQD`)6A-`J@`LM\M<,,!`_C9?28HK0`F&+@`^L89`"V00@)X*1D`+8!0`B4H
MN``#^&-\`_BE?"T8<`"XQQ$`L`"PW[J($0`M&&4`)<`1`P/X<7PF*+@!+8`"
M`B8HK@#ZEA$`>'$1`"UX#P(ED-(!`_BE?"THKP`#^%)^+9"R`+A_&0"X`*7?
MNL@9``/XK7TE>/D!`_A9?B9P#P,M**(`)AC#`?J&&0!X<1D`+2BM`"6`T`$#
M^&-\+1BC``/X$'XM@'``N'<1`,``H]^ZB!$``_@8?R5PT0$#^!%^)BCN`2T8
M8@`F*+(`>&D1`/J6$0`M&'@``_BE?"5HL@$M&&4``_BM?2UH;0"XQQD`R`"C
MW[K(&0`#^.]])<`9`P/XN7TF*-@!^I89`":`L``M&&(`>"D9`"T8;P`E*+(`
M`_@/?BT8;P`#^*5\+2AE`+A_$0#0`*/?NH@1``/XL'PE>/$!`_C2?2:(#P,M
M&&(`)G`M`GB)$`#Z;A``+1AR``/XSGTE:"T"+1AN``/XK7TM:&T`N'<9`-@`
MH]^ZR!D``_@2?R5PV0$#^+E])HCN`2T88@`FP"4">(D9`/HN&0`M&'(``_@8
M?R4H)0(M&'@``_BE?"TH90"XQQ``X`"CW[J`$``#^/)])<`0`P/XL'PFB-@!
M+1AB`"9X+0)XB1``^FX0`"T8<@`#^.]])6@M`BT8;P`#^*U]+6AM`+A_&0#H
M`*/?NL@9``/XTGTE>/D!`_BY?2:(#P,M&&(`)G`E`GB)&0#Z+AD`+1AR``/X
MSGTE*"4"+1AN``/XI7PM*&4`N'<0`/``H]^Z@!```_@2?R5PT`$#^+!\)HCN
M`2T88@`FP"T">(D0`/IN$``M&'(``_@8?R5H+0(M&'@``_BM?2UH;0"XQQD`
M^`"CW[K(&0`#^/)])<`9`P/XN7TFB-@!+1AB`"9X)0)XB1D`^BX9`"T8<@`#
M^.]])2@E`BT8;P`#^*5\+2AE`+A_$````:/?NH`0``/XTGTE>/`!`_BP?":(
M#P,M&&(`)G`M`GB)$`#Z;A``+1AR``/XSGTE:"T"+1AN``/XK7TM:&T`N'<9
M``@!H]^ZR!D``_@2?R5PV0$#^+E])HCN`2T88@`FP"4">(D9`/HN&0`M&'(`
M`_@8?R4H)0(M&'@``_BE?"TH90"XQQ``$`&CW[J`$``#^/)])<`0`P/XL'PF
MB-@!+1AB`"9X+0)XB1``^FX0`"T8<@`#^.]])6@M`BT8;P`#^*U]+6AM`+A_
M&0`8`:/?NL@9``/XTGTE>/D!`_BY?2:(#P,M&&(`)G`E`GB)&0#Z+AD`+1AR
M``/XSGTE*"4"+1AN``/XI7PM*&4`N'<0`"`!H]^Z@!```_BQ?"5PT`$#^!)_
M)H#N`2T88@`FP`T">($1`/IN$0`M&'(``_@8?R5H#0(M&'@``_BM?2UH;0"X
MQQD`*`&CW[K(&0`#^+!])<`9`P/X\GTFR-@!+1AB`"9X)0-XR1``^BX0`"T8
M<@`#^.]])2@E`RT8;P`#^*5\+2AE`+C/$0`P`:/?NH@1``/XTGTER#$#`_BQ
M?"9X&0,M&&(`)FCM`?IV$0!X>1$`+1AR``/XK7TE<.X!+1AM``/XSGTM<&X`
MN'\0`#@!H]^Z@!```_@2?R5X\`$#^-!])F@O`RT88@`FP*4!>&D0`/HN$``M
M&'(``_@8?R4HI0$M&'@``_BE?"W`90"X;Q$`0`&CW[J($0`#^#E_)6BQ`0/X
M$7\F*.T!+1!B`"9PK@#Z'A$`>"D1`"T060`#^-E]N'<0`+J`$``E&*,`)7#0
M`2T060`E**X!`_AC?"V`0P`D*+@`2`&XW\8C`CP#^!E^-^]"-"08K@&X$`(`
M)2BC`"W``@-X&1D``_CR??I^&0`MD!(#)7AO`+C'$0`#^*5\NH@1`"THL@!0
M`;+?)<`1`P/X[WTE&-@!+2BO`"08<``D>-@!`_BP?"48;P#ZCA``>'D0`"V0
M0@(EB/$!`_BM?;A_&0"ZR!D`+6A-`B5X^0$#^&-\`_@Y?E@!L=\M&&T`)6@/
M`RT8>0`D**4!)&@/`P/X>7PE**T`+8@B`@/XSGWZEAD`+8@N`GAI&0"X=Q``
M`_BE?+J`$``E<-`!)6BR`2THL0!@`;'?`_BP?25H[@$M*+``)!BC`21H[@$#
M^+!\)1AM`"V((@(#^!A_^I80`"V(.`)X:1``N,<9``/X8WRZR!D`)<`9`R5H
ML@$M&'$`:`&QWP/XN7TE:-@!+1AY`"0HI0$D:-@!`_AY?"4HK0`MB"("`_CO
M??J6&0`MB"\">&D9`+A_$``#^*5\NH`0`"5X\`$E:+(!+2BQ`'`!L=\#^+!]
M)6@/`RTHL``D&*,!)&@/`P/XL'PE&&T`+8@B`@/XSGWZEA``+8@N`GAI$`"X
M=QD``_AC?+K(&0`E<-D!)6BR`2T8<0!X`;'?`_BY?25H[@$M&'D`)"BE`21H
M[@$#^'E\)2BM`"V((@(#^!A_^I89`"V(.`)X:1D`N,<0``/XI7RZ@!``)<`0
M`R5HL@$M*+$`@`&QWP/XL'TE:-@!+2BP`"08HP$D:-@!`_BP?"48;0`MB"("
M`_CO??J6$``MB"\">&D0`+A_&0`#^&-\NL@9`"5X^0$E:+(!+1AQ`(@!L=\#
M^+E])6@/`RT8>0`D**4!)&@/`P/X>7PE**T`+8@B`@/XSGWZEAD`+8@N`GAI
M&0"X=Q```_BE?+J`$``E<-`!)6BR`2THL0"0`;'?`_BP?25H[@$M*+``)!BC
M`21H[@$#^+!\)1AM`"V((@(#^!A_^I80`"V(.`)X:1``N,<9``/X8WRZR!D`
M)<`9`R5HL@$M&'$`F`&QWP/XN7TE:-@!+1AY`"0HI0$D:-@!`_AY?"4HK0`M
MB"("`_CO??J6&0`MB"\">&D9`+A_$``#^*5\NH`0`"5X\`$E:+(!+2BQ`*`!
ML=\#^+!])6@/`RTHL``D&*,!)&@/`P/XL'PE&&T`+8@B`@/XSGWZEA``+8@N
M`GAI$`"X=QD``_AC?+K(&0`E<-D!)6BR`2T8<0"H`;'?`_BY?25H[@$M&'D`
M)"BE`21H[@$#^'E\)2BM`"V((@(#^!A_^I89`"V(.`)X:1D`N,<0``/XI7RZ
M@!``)<`0`R5HL@$M*+$`L`&QWP/XL'TE:-@!+2BP`"08HP$D:-@!`_BP?"48
M;0`MB"("`_CO??J6$``MB"\">&D0`+A_&0`#^&-\NL@9`"5X^0$E:+(!+1AQ
M`+@!L=\#^+E])6@/`RT8>0`D**4!)&@/`P/X>7PE**T`+8@B`@/XSGWZEAD`
M+8@N`GAI&0"X=Q```_BE?+J`$``E<-`!)6BR`2THL0#``;'?`_BP?25H[@$M
M*+``)!BC`21H[@$#^+!\)1AM`"V((@(#^!A_^I80`"V(.`)X:1``N,<9``/X
M8WRZR!D`)<`9`R5HL@$M&'$`R`&QWP/XN7TE:-@!+1AY`"0HI0$D:-@!`_AY
M?"4HK0`MB"("`_CO??J6&0`MB"\">&D9``/XI7PE:+(!N'\0`"THL0"Z@!``
MT`&QWR5X\`$#^+!]+2BP`"5H#P,#^+!\)!BC`2V((@(D:`\#`_C.??J6$``M
MB"X")1AM`+AW&0!X:1``NL@9`"5HL@$E<-D!`_BY?25H[@$#^&-\)"BE`21H
M[@$E**T`V`&MWRT8<0`#^!A_+1AY``/X>7P#^*5\+6BB`?J6&0`M:+@!N,<0
M`+J`$`!XB1D`)<`0`RUHK0`E*-@!)8@R`B08HP`D*-@!`_@P?B4890#@`:7?
M+6BP`0/X[WT#^+!]`_AC?"T0H@#ZCA``>"D0`"UX3P`E*+$`+1!O``/XHWRX
M?QD`Z`&EWRT80P"ZR!D`,64"/"5X^0'K8$)D`_AY?'@0`@`FB`\#^I89`"TH
MH@`#^,Y])F@M`GB)&0`M**X``_BM?26(,@(M**T``_@Q?BV(L0"X;Q``\`&E
MW[J`$``#^!A_)6BP`0/X,'XF<.T!^I80`"THH@`F&,,!>'$0`"THN``E<-(!
M`_AC?"T8HP`#^,5]+2AE`+AW&0#X`:/?NL@9``/X[WTE<-D!`_BY?";`K@'Z
MEAD`)H@1`RT88@!XP1D`+1AO`"7`$@,#^"]^+1AO``/X&'\MP'@`N'\0```"
MH]^Z@!```_BR?25X\`$#^!!_)HC/`2T88@`F*"4"^FX0`'B)$``M&'(``_BE
M?"5H+0(M&&4``_BM?2UH;0"X+QD`"`*CW[K(&0`#^-)])2BY``/XN7TFB.4!
M+1AB`"9P.`)XB1D`^L89`"T8<@`#^,Y])<`X`BT8;@`#^!A_+<!X`+AW$``0
M`J/?NH`0``/X\GTE<-`!`_@0?R:(K@`M&&(`)F@M`OI^$`!XB1``+1AR``/X
MK7TE>"\"+1AM``/X[WTM>&\`N&\9`!@"H]^ZR!D``_BR?"5HN0$#^/E])HC-
M`2T88@`F*#@">(D9`/K&&0`M&'(``_BE?"7`.`(M&&4``_@8?RW`>`"X+Q``
M(`*CW[J`$``#^-)])2BP``/X$'\FB*4!+1AB`"9P+P)XB1``^GX0`"T8<@`#
M^,Y])7@O`BT8;@`#^.]]+7AO`+AW&0`H`J/?NL@9``/XLGTE<-D!`_CY?2:(
MK@`M&&(`)F@X`GB)&0#ZQAD`+1AR``/XK7TEP#@"+1AM``/X&'\MP'@`N&\0
M`#`"H]^Z@!```_BR?"5HL`$#^!!_)HC-`2T88@`F*"\">(D0`/I^$``M&'(`
M`_BE?"5X+P(M&&4``_CO?2UX;P"X+QD`.`*CW[K(&0`#^-)])2BY``/X^7TF
MB*4!+1AB`"9P.`)XB1D`^L89`"T8<@`#^,Y])<`X`BT8;@`#^!A_+<!X`+AW
M$`!``J/?NH`0``/XLGTE<-`!`_@0?R:(K@`M&&(`)F@O`GB)$`#Z?A``+1AR
M``/XK7TE>"\"+1AM``/X[WTM>&\`N&\9`$@"H]^ZR!D``_BR?"5HN0$#^/E]
M)HC-`2T88@`F*#@">(D9`/K&&0`M&'(``_BE?"7`.`(M&&4``_@8?RW`>`"X
M+Q``4`*CW[J`$``#^-)])2BP``/X$'\FB*4!+1AB`"9P+P)XB1``^GX0`"T8
M<@`#^,Y])7@O`BT8;@`#^.]]+7AO`+AW&0!8`J/?NL@9``/XLGTE<-D!`_CY
M?2:(K@`M&&(`)F@X`GB)&0#ZQAD`+1AR``/XK7TEP#@"+1AM``/X&'\MP'@`
MN&\0`&`"H]^Z@!```_BR?"5HL`$#^!!_)HC-`2T88@`F*"\">(D0`/I^$``M
M&'(``_BE?"5X+P(M&&4``_CO?2UX;P"X+QD`:`*CW[K(&0`#^-)])2BY``/X
M^7TFB*4!+1AB`";`.`+Z=AD`>(D9`"T8<@`#^!A_)7`N`BT8>``#^,Y]+7!N
M`+C'$`!P`J/?NH`0``/XLGTEP!`#`_C0?2:(N``M&&(`)F@O`GB)$`#Z?A``
M+1AR``/XK7TE>"\"+1AM``/X[WVXCQD`NF@9`"W(;P!X`J/?)6@M`@/X+W\F
MB`T#`_BR?"9P+@(M&&(`>(D/`/HN#P`#^,Y]+1AR`"4H)0(M&&X``_BE?+AW
M$``M*&4`@`*CW[J`$``#^*5\)7#0`0/X&'\F@*X!+1AB`";(&0+Z%@4`>($%
M`"T8>``E$`("`_@X?RT8>``#^$)\+1!B`+@?#P`#^$)\NG@/`"T03``E&&\`
M`_A"?`/X8WP``(+\`_C.?0/XHGT``"G=+3CE`"T8:``M4,H!+1!+``/XYWP#
M^&-\`_A%?0/X0GP(`(?\$`"#_!@`A?P'`,D4(`""_#\+O,OU"K3+LPJRRW$*
ML,L(`.`#T`*]9[B"F=\)^"`#`````$<`@!``````L/^]9S\!O.L"`!P\"`"P
M_RW@F0/H^)QG*(&"W_8`M>NT`+/K<@"QZP``5=PC`*`2````````@H`U`$`0
M/0`#)#,`0Q`E$(``/0`&)`$`0F0``$.``P!@$"^01`#\_V84`0!"9`"0$@``
M`+#>$P``$B68H``EH(``)8B@`CT`%B0P@9G?`````"4@``(E,$`""?@@`R4H
M@`($`$`4``````"0`MH.`%80`0!"9@@`,68``##>]/\`%C"!F=\_`;S+]@"U
MR[0`L\MR`+'+"`"PWR40```(`.`#4`"]9P`````OB#4"^X@1`"T0`@(``'&N
M/P&\R_8`M<NT`+/+<@"QRP@`L-\(`.`#4`"]9P````#5_P`0)9````@`X`,E
M$```L/^]9S\!O.L"`!P\&`"P_RW@F0/`]YQG]`"SZ^B"D]\$`+1GL@"QZTB`
MD-\EB(````!BWBB!DM](-Q!F"`"B_R4H@`(ER``"H_\1!"4@(`(1`$`0!`"B
MC_@8`@```$+>+1!#``@`0]SU_V`0``!#_`@`0F0(`$/<_?]@%```0_PE*(`"
M)<@``I/_$00E("`"\?]`%`0`HH\(`*/?``!BW@8`8A08`+#?/P&\R_0`L\NR
M`+'+"`#@`U``O6>X@IG?"?@@`P````"@_[UG?P&\ZP(`'#P8`+#_L@"QZ_0`
ML^LV`;7K+>"9`P``HH`EF(``^/:<9^B"DM\]`$(X`(*9WP$`0BP``$/>+8"B
M`"4@``((`*/_"?@@`P`````$`*5G2("9WR4@8`)(-SEG:O\1!"6(0`!8`$`0
M`(*9WR4@0``)^"`#):!```/X(WXK$$,`10!`$"B!E=\$`+2/``!B@G@`0!`]
M``,D=@!#$#T`!"0#```0)1!@`@4`9!```````0!"9```0X#[_V`4`````"\0
M4P``$`(``"`1````H]X#^)1^.(*9WP(`A"3XH!0`(2""``/XA'P)^"`#+:!T
M`&4`0!```(+^*(&"WP$`9&8$`*.?``!E@@``0MSX&`,``QA#V`T`H!```&6@
M/0`")`H`HA```````P``$#T`!20&`$40``````$`A&3__X*``0!C9/K_0!0`
M`&*@/0`$)`$`8F0``&2@`0`09O__`X(!`$)D_/]@%/__0Z`E$```"`"DWP``
M0]Y%`(,4&`"PWW\!O,LV`;7+]`"SR[(`L<L(`.`#8`"]9P$`$&;__P*"`0"4
M9O'_0!#__X*B`0`09O__`H(!`)1F]_]`%/__@J+K_P`0)1```"B!E=\``+;>
M``#"WBD`0!`E$,`"`P``$"4@````````)2!@``@`0F0``$7<`0"#)/O_H!0E
MH&```P"$)/@@!``X@(+?@,-#C`T`8!`X@IG?0(*9WR4H@``)^"`#)2#``A<`
M0!```*+^`0"#9O@8`P`M$$,```!`_)+_`!`$`+2O`0`#)`GX(`.`PT.L#`!`
M$`"#F=_X,!0`)2C``@GX(`,E($``\/\`$```HOZ4_P`0)1```!``!"3A_P`0
M):```+G_`!#__P(DN(*9WPGX(`,``````````,#^O6>\!+?K`@`</.@`L/\M
MX)D#4/2<9S0$L^OH@I/?_P2^ZW8$M>OR`['K``!BWM@`HO\$`(`0````````
M@H`-`$`4)8B``-@`H]\``&+>7P!B%.@`L-__!+[+O`2WRW8$M<LT!+/+\@.Q
MRP@`X`-``;UG`````/B`F=\)^"`#`````/#_0!`ED$``2("5WRX`%"0E\*`#
M2("6WTADM69(@9G?``````GX(`,E($`",0!`$`"!F=\3`$.0-@!T$`""F=\E
M("`""?@@`Q,`4&0`@IG?)2```@GX(`,EN$``.(*9WRT0X@(`(`(`"?@@`P(`
MA"3P@)G?)4@``B5`(`(E($``)3B@`O__!B0!``4D"?@@`R6`0``@@9G?)3#`
M`R4H``()^"`#`P`$)/__`R0%`$,0(`"BCP!``R0`\$(P'P!#$.`[V6:@@IG?
M"?@@`R4@``+X@IG?"?@@`R4@``)(@9G?"?@@`R4@0`+2_T`4`(&9WP`````)
M^"`#)2!``M""F=\)^"`#)2`@`J[_`!```````````!0`0Y#"_V`02(&9W\?_
M=!0`@IG?%0!#D+O_8!`E("`"P_\`$`````"/_Q$$)2```N/_`!#X@IG?N(*9
MWPGX(`,``````````.#_O6=_`+SK`@`</"W@F0-P\IQG,0"PZZB"D-\EB(``
M&(&9WPGX(`,```2.$(&9WR4H(`+X`49D"?@@`P,`!"0'`$`0&(&9WW\`O,LQ
M`+#+)1````@`X`,@`+UG``````GX(`,```2.`$`#)!@"0HP`\$(P"`!#$!B!
MF=\)^"`#```$C@"@`S08`D*,`/!",.W_0Q0`````@(&9WR4@(`()^"`#`@`%
M)'\`O,LQ`+#+`0!"+`@`X`,@`+UG`````+#OO6?_#P8D0!"\_P(`'#PMX)D#
M*!"R_[#QG&<P$+/_)9B``.B"DM](@(3?.!"T_R6@H``@$+'_"`"Q9T@0O_\E
M*"`"4&2$9!@0L/^`@IG?``!"W@@0HO\)^"`#```````0`@`D`$`8$!"C9___
M4"0M&'``^.]C@!T`8!"P@9G?)8!``"4P``(O``4D"?@@`R4@(`(8`$`0J(*"
MWQB!F=\)^"`#``!$C%B!F=\E.``")3`@`B4H8`()^"`#)2!```@0H]\``$+>
M%@!B%$@0O]]`$+S?.!"TWS`0L]\H$++?(!"QWQ@0L-\(`.`#4!"]9^3_`!8`
M````J(*"WQB!F=\)^"`#``!$C'B"F=\E,(`")2A@`@GX(`,E($``Z/\`$```
M``"X@IG?"?@@`P````#P_[UG/P"\ZP(`'#PMX)D#@/"<9ZB"@M\8@9G?"?@@
M`P``1(Q0@(??2("%WR4@0`#@@9G?V(*&WUBFYV0)^"`#8&2E9#\`O,L(`.`#
M$`"]9^#_O6=_`+SK`@`</`@`L/\MX)D#,/"<9ZB"D-\8@9G?"?@@`P``!(Y8
M@)G?X/\1!"4@0``8@9G?"?@@`P``!(Y(@(C?)4@``$B`A=\E($``B(&9WV"`
MAM]8:`AE)3@``0GX(`.`9*5D"`"PWW\`O,L(`.`#(`"]9Z#?O6=0(+S_`@`<
M/"W@F0-`(+'_N.^<9U@@O__H@I'?.""P_Q@`L&=0@IG?2""R_P``(MXH(*+_
M"?@@`P`````!$`8D2(")WR5`0``!``4D2("'WR4@``+P@)G?F&0I90GX(`.@
M9.=D'P!`!(""F=\@$+)G)2```@`0!B0)^"`#)2A``@P`HJ\,`+"/%@``!CB"
MF=\)^"`#`0`$)A(`0!#P@IG?)2A``B4@0``)^"`##`"FCRV`4`````"B*""D
MWP``(]X*`(,46""_WU`@O-]((++?0""QWS@@L-\(`.`#8""]9P````#T_P`0
M)1```+B"F=\)^"`#```````````"``,\+1AY`+CN8V1H@'G<N_\`$`````"`
M[[UG:!"\_P(`'#PMX)D#*!"P_R6`@`"@[IQG>!"__^B"@M](@(3?2("9WS@0
MLO\P$+'_N&2$9"6(H`!P$+[_%`"E9T@W.6=@$+?_6!"V_U`0M?]($+3_0!"S
M_P@`HO\``$+<&!"B_U/]$00`````+P`%)!""F=\E(``""?@@`R600``9`$`0
M`(*9WTB`A-\E*``"2("9WS@Y.6?"_1$$R&2$9"40``((`*/?&!"DWP``8]QQ
M`(,4>!"_WW`0OM]H$+S?8!"WWU@0MM]0$+7?2!"TWT`0L]\X$++?,!"QWR@0
ML-\(`.`#@!"]9R4@``()^"`#2("4WWB!F=\E("`"`!`"`-ADA68E&$``"?@@
M`P``H__=_T`0);!``$B`GM](@)??2("5W^!DWF?H9/=F``##@K!DHF8'`$`2
M"K!#`"B#F=\E*,`""?@@`R4@0`(S`$`0>(&9WP""F=\)^"`#)2#``B\``R0`
M$`(`+2#"`O__A(`'`(,4+P`%)`````#__T(D+1C"`O__9(#\_X40``!@H```
MHX\!`&,D(1!B```00BBY_T`0\("9WQ@`L6<E4``"J(*3WR5(P`,E0,`")3C@
M`@`0!B0!``4D"?@@`R4@(`(8@9G?"?@@`P``9(X@@9G?)2@@`O@!1F0)^"`#
M`P`$)`H`0!1X@9G?&(&9WPGX(`,``&2.`(`#-!@"0HP`\$(P"0!#$("!F=]X
M@9G?V&2%9@GX(`,E(```P/]`%"6P0`"6_P`02("$WP$`!20)^"`#)2`@`O7_
M0!1X@9G?2("$WR4H(`)(@)G?.#DY9U']$03(9(1DR(&9WPGX(`,E("`"C?\`
M$`@`H]^X@IG?"?@@`P```````(6`!P"@$"40@``!`(-D+P"D.```98`*$&0`
M_/^@%`$`8V0(`.`#``````````#@_[UG?P"\ZP(`'#PMX)D#,0"PZR``@!#H
MZYQG``"1@!T`(!(E@(```(*9WPGX(`,`````__]"9"T0`@(K&`("+@!@$"\`
M`R0``$2`(@"#%``````%```0+P`$)````````$.`'`!D%`````#__T)D^_\"
M%@`````O``(D!@`B$DB`A-_(@9G?"?@@`^!DA&0'```0`````#B"F=\)^"`#
M`@`$)`8`0!`N``0D``!$I'\`O,LQ`+#+"`#@`R``O6=_`+S+,0"PRR40```(
M`.`#(`"]9P`````$```0+P`$)```0X`'`&00`````/__0F0K&`("^O]@%```
M``#>_P(2``````4``!`O``0D````````0X`&`&04`@##9/__0F0K&`("^O]@
M%"\P4``"`,-D`1!C+.+_8!`X@)'?)2@``@`0!R28@9G?`0#&9`GX(`.`LR1F
M@+,B9G\`O,LQ`+#+"`#@`R``O6=P_[UG/P*\ZP(`'#PMX)D#@.J<9U"`@]]S
M`;+KZ(*3WPP`LF<Q`;#K2("0WS"F8F3W`;;KM0&TZTB`A-]P.!!F,*9GW"7(
M``((`$;<$`!%W/!DA&08`$/<``!HWB``0I00`*?_.`"H_Q@`IO\@`*7_*`"C
M_Y+\$00P`**G)<@``DB`A-](@)3?2("5WP!EA&2+_!$$2("6WTB`A-\ER``"
M2("7WTB`D=^%_!$$"&6$9$B`A-\ER``"2#<Q9H#\$008981D)<@``GW\$00@
M981F2("$WR7(``)Y_!$$,&6$9"7(``)V_!$$N&2D9B7(``)S_!$$0&7$9B7(
M``)P_!$$4&7D9DB`A-\ER``";/P1!&!EA&1(@(3?)<@``FC\$03(9(1D2("$
MWR7(``)D_!$$<&6$9$B`A-\ER``"8/P1!(!EA&1(@(3?)2A``B7((`(1_!$$
MD&6$9"L`0!`E*$``2("0WS@Y$&8ER``"AOP1!%!EY&9(@(3?)2A``B7((`(%
M_!$$J&6$9`4`0!`E*$``2("$WR7(``)[_!$$P&6$9$B`A-\E*$`")<@@`OK[
M$030981D&`!`$"4H0``ER``"<?P1!+ADI&9(@(7?(&6$9B7(``)L_!$$"&:E
M9#@`H]\``&+>)0!B%+B"F=\_`KS+]P&VR[4!M,MS`;++,0&PRP@`X`.0`+UG
M2("0W]G_`!`X.1!F`````$B`A-\E*$`")<@@`MS[$03@981D!@!`$"7(``(E
M*$``4_P1!$!EQ&;B_P`02("%WTB`A=\*``8D(0"D9S"!F=\)^"`#^&6E9-G_
M0!0ER``"*P"E9T;\$01`9<1FU?\`$$B`A=\)^"`#``````````#0_[UG__\#
M)+\`O.L"`!P\+>"9`_CGG&=Q`+#KZ(*0WSB`D=\```3>$+`BC@@`I/\)`$,0
M2("$WP@`I-\```/>%@"#%+B"F=^_`+S+<0"PRP@`X`,P`+UG!`"E9TB`F=](
M-SEGJOL1!$!EA&0(`$`0````````0X`#`&`0)1```#``8C@K$`(`Z_\`$!"P
M(JXE$```Z/\`$!"P(JX)^"`#``````````#P_[UG/P"\ZP(`'#PMX)D#4.><
M9[""F=\)^"`#`````!"#F=\)^"`#)2!```8`0!````````!"W#\`O,L(`.`#
M$`"]9P````#[_P`0)1```##_O6?\`K?K`@`</'@`L/\P`+!G+>"9`V``H/\`
MYYQGZ(*"WS("L>NV`K7K)1A```@`HO](@(+?=`*SZS\#ONL09D)D):"``$B`
MEM\EB$``.`"B_RP`OF=(@(+?2("$WP``9=SH9,-F*&9"9$B`D]]``*+_&&:$
M9$B`@M\ED(``2("7WT@W<V9(@)7?,&9"9!``H_](`*+_V&3W9DB`@M\P`*3_
M:`"E_SAF0F10`*+_2(""WU!F0F0*```06`"B_R4H@`()^"`#)2#``B(`0!``
M@IG?$P`@$@@`$&8ED"`""``1WB4HP`,ER&`"2OL1!"4@0`($`$`0);!`````
M0H#O_T`4,(.9WR4H@`(E($`".#FY9KS[$00(`!!F\/\@%B60(`((`*+?:`"C
MWP``0MPE`&(4>`"PWS\#OLO\`K?+M@*URW0"L\LR`K'+"`#@`]``O6<`````
M"?@@`R4@@`(`@IG?)2#``@GX(`,8`*+_&`"EWSB"F=\M$*(`"?@@`P(`1&00
M`*??)5#``O"`F=\E2.`")2!``"5`@`+__P8D&`"B_PGX(`,!``4D&`"KWR4@
M0`(X.;EFD_L1!"4H8`'$_P`0`````+B"F=\)^"`#```````````0@+UGV'^\
M_P(`'#PMX)D#P'^U_R6H@``HY9QGN'^T_U"!!#3H@H+?J'^R_Z!_L?_H?[__
M)1A``.!_OO_0?[?_R'^V_[!_L_^8?[#_`/Z]9T``IF<@`*+___\"/"T@A@#,
M?D5D2("4WRT0@@!0@00T+2"&````9MPM*(4`2("$WT@WE&9(@(/?)<B``N!^
M0/S`99)D2("$WW!F8V0`?U+\T'Y#_$B`@]\E.(``,`"D_TB`A-^P9&-D*']`
M_-A^0_Q(@0,T8&:19+ADY&3X?D#\0`"G9^A^4?PM&&<```!F_$B`@]]X9F-D
M"']#_$B`@]^`9F-D$']#_$B`@]^(9F-D&']#_$B`@]^09F-D(']#_$B`@]^8
M9F-DR?H1!/!^0_P$`$`0<("9WP``0X!@`6`4)2!``"C_$00`````90%`$"68
M0```@IG?"?@@`R4@8`)X$`(``0!$9#B"F=\)^"`#````````8X(1`&`0)8A`
M`$B`A]\EL$``J&;P9````````&B2)2#``B4X``+P@)G?__\&)`$`!20!`'-F
M"?@@`P(`UF8``&*"]?]`%`````#__Q8\0`"C9TB`D]]0@0(T`'_09BT00P#,
M?M9F+8!0`%"!`C0M$$,`)2!``@<``!`ML%8```````@`$&8````````$WA0`
M@!!0@0(T)<B``H_Z$00E*,`"]_]`$"600````$*`]/]`$,`]>68F_!$$)2!`
M`O+_0!`(`!!F^/\09LB!F=\)^"`#)2!``B4`0!0EL$``4($"-$``HV?__Q(\
M+1!#`"V04@#0?E;>'`#`$@```````,*"&0!`$`$`%R1(@)/?"@``$,`]<V8`
M````^(`0`"V`4`+0?A;>$`#`$@```````,*"#0!`$`$`]R8ER&`"!/P1!"4@
MP`+T_T`0)8#@`LB!F=\)^"`#)2#``N__0!`EL$```P``$`""F=\EL````(*9
MWR4@P`()^"`#2("3WP""F=\E("`""?@@`R6`0``X@IG?+1`"`@`0`@`$!$(D
M)2!```GX(`,E@$``2("*WR58(`)(@(??X&1I9B4@0`#P@)G?)4#``O__!B2P
M9DIE`0`%)+AFYV0)^"`#)9!``-"!F=_``04D"?@@`R4@0`+__P,D+0!#$+B!
MF=^H@I'?&(&9WPGX(`,``"2.$(&9WR4H0`+X`49D"?@@`P,`!"0R`$`0&(&9
MWPB#@M\E0$`"`0`%)$B`AM]`@9G?``"GW@``1-P)^"`#4&?&9"40``!``*1G
M2($#-"T89````&3<(`"CWP``8]R6`H,4N(*9WP`"O6?H?[_?X'^^W]A_O-_0
M?[??R'^VW\!_M=^X?[3?L'^SWZA_LM^@?['?F'^PWP@`X`/P?[UG``````GX
M(`,`````$0`#)```28S/_R,1"(."WR5`0`(!``4D2("&WT"!F=\``*?>``!$
MW`GX(`/(9L9DVO\`$"40```)^"`#```DC@!``R08`D*,`/!",,K_0Q0(@X+?
M&(&9WPGX(`,``"2.L(*9WPGX(`,H`E:,PO]6%`B#@M\8@9G?"?@@`P``)([`
M`0,D&`)"C/\!0C"Z_T,4"(."WSB"F=\)^"`#)2```DB`A-]``*-G)8A``/__
M!3Q0@0(TS'ZE9"T00P`P9H1D)<B``MCY$00M*$4`H`!`$,B!F=\E($``"?@@
M`P``L-YX@)G?)2A``&'\$00E(``"EP!`$"6@0```@IG?"?@@`R4@@`(`$`(`
M)8!```0`0B@3`$`4@("9WTB`A=_\_P1F*(.9WRT@A`()^"`#"&>E9`L`0!2`
M@)G?!``").4!`A+\_P(F+P`#)"T0@@+__T*`X`%#$`````"`@)G?`````.W]
M$00`````"`!`%$B`GM_P@9G?)2@```GX(`,E((`"=0!`%"@`HO](@)[?__\5
M)!$`%B1(@(7?2("$WS@YWF=(@)#?"&:E9"7(P`-(@)3?&?H1!$!EA&10@IG?
M6&@79CAGE&8)^"`#)8```$B`A]\E6.`"\("9WR500`#@9&EF)4!``O__!B0H
M9^=D`0`%)`GX(`,E("`"%```$-"!F=\)^"`#````````0HP4`%844(*9WPGX
M(`,!`!`F\("9WR58``(E4$``X&1I9@``M_\E0$`")3B``O__!B0!``4D"?@@
M`R4@(`+0@9G?P`$%)`GX(`,E("`"Z?]5$+B!F=_X@IG?"?@@`R4@0`(P`*+?
M)2@@`B7(P`/G^1$$N&1$9(B`F=_B_1$$)2`@`D/_`!`E$"`"`````(B`F=_<
M_1$$&`"B_Q@`HM_(@9G?"?@@`R4@0``Z_P`00`"D9___$#Q``*-G4($"-,Q^
M%F8M$$,`)2`@`BVP5@!0@0(T+1!#``$`$20M@%``)<B``D[Y$00E*,`"!`!`
M$"48(`(``$.`"P!@%"48(`+X&`,`+1@#`NA^9-ST_X`4`0`Q)DB`D]\-``0D
MAOX`$&AF<V8`````R(&9WPGX(`,E($``\O]`$"48(`)Y_@`0)9A```````!I
M_P`0``"TWEB"F=\E($```@`&).[_!20EJ$``"?@@`___$#Q``*-G((.9WU"!
M`C3X?Q1F+1!#``8`!B0MH%0`)2"@`@GX(`,E*(`"0`"C9U"!`C0M$$,`+1!0
M`/A_0Y`$`&`40P`$)/E_0Y!L`60000`$)%B"F=\E,```)2@``"@`I-\)^"`#
M2("5WT``I&=(`+'_4($#-/__`CPM&&0`,'](9"T08@!%9P,\`2-C9"6P0`!8
M?T#\,']#_.=W`R1X'`,`8']`_(FK8V2H?T"L.']#_%"!`S0M&&0`__\$//A_
MA#0M\&0`0`"D9U"!`S1``+[_+1AD`#T,!#PMN&@`74P#/']N8V0?+H1D>!@#
M`#@A!`!`?T/\,A`#/'948V10?T3\2']#_!`?HV88`*/_.`#C9C@`H_\@@YG?
M`(`&-"4HP`,H`*3?"?@@`___%#P`$`(`)8!``%\`0!@EJ$``6'_#WO@0$``M
M$$,``_A"?"L80P```6`4`````&!_Q=ZH?\2.>A\0`"T890!8?\+^\0"`$&!_
MP_XX`*+?0``5)".@I`+P@IG?0`"EWRT@1``J$)`""J`"`@GX(`,E,(`"J'_"
MCB$05`#;_U44J'_"KA@`N=\E(.`""?@@`R.H%`)``*+?+:!4`$``HBHI`$`4
M)8"``B6(H`('``MJP/\Q)B4@X`(/``EJ%P`(:A\`!VHG``9J+P`%:C<``VH_
M``)J```+;@@`"6XX``)N$``(;A@`!VX@``9N*``%;C```VY``!!F:'_+_A@`
MN=^@?\+^<'_)_GA_R/Z`?\?^B'_&_I!_Q?X)^"`#F'_#_D``(BKA_T`0````
M`,#_M2:"&14``0!D9(`9`P"X(00`(ZBC`BV@A`(H@IG?)3"@`B4H@`(X`*3?
M2``')`GX(`/__Q0\*`"DWP"`!C0@@YG?)2C``PGX(`.H?]6N`!`"`"6`0`"C
M_T`<):A```B!F=\H`*3?"?@@`T@`L=]``*-G4($"-$``I6<M$$,`4($#-"T0
M5``M&&4`6']6W(#_!21@?U[<PRC"?@$`1"0M$&(`+1""`CD`@RBG`&`0:']%
MH$``HV=0@0(TV(&9WRT00P`X``8D+1!4`",PQ`!H?T)D)2@```GX(`,M($0`
M0`"E9U"!`C08`+G?__\0/"T010!``*AG4($'-"VX4``M..@`.AX>`#H4'@"C
M?_ZB,'\$9CHR'@"@?^.B.BX6`#H<%@"A?^*B+2#D`#H2%@"B?^:BI'_EHJ5_
MXZ*F?^*B"?@@`Z=_]J)``*-G4($"-+!_%F8X?^7>+1!#`,A_$&9`?^3>+;!6
M`%"!`C0P?^;>+1!#`$A_X]XZS@4`+:A0`%!_XMXZQ`4`,W_PDCI$!@`Z\@8`
M2("'WSI>`P`Z5`,`.DH#`#IZ!0"S?^:B.G8$`#IL!`"_?^.B.F($`#K\`@"P
M?_"B.C("`#H>`@"Q?^BB`0#49O\`"#*R?_ZB%`#69JAF\&2T?_FBM7_XHK9_
M[Z*W?^6BN'_NHKE_[:*Z?^RBNW_DHKQ_ZZ*]?^JBOG_IHL!_XZ+!?_^BPG_F
MH@0``!##?^*B````````B)(!`)1F\("9WR4@H`(E.``"__\&)`$`!20)^"`#
M`@"U9O;_U!9``*1G4($#-$B`B]\M&&0`__\"/$B`A]_P@)G?R']*9"T08@!0
M@0,TX&1I9O!_0*`M&&0`)4!``DB`GM\M4&H`6&AK9?__!B089^=D`0`%)`GX
M(`,E("`"^(*9WR4@0`()^"`#.#G>9S``HM\E*"`")<C``V+X$02X9$1DB("9
MWUW\$00E("`"OOT`$"40(`)``*-G4($"-"T00P#__P,\^']C-![_`!`MH$,`
M`````&!_P]X`_P`0`0!E9`@`L-X?_@`2`(*9WPGX(`,E(``"!`!#+!S^8!2`
M@)G?2("%W_S_1&0H@YG?+2`$`@GX(`,09Z5D$OX`$`J@`@)``*-G4($"--B!
MF=\M$$,`,'^49BV@5`!```8D.`"09B,PQ``E*```"?@@`RT@!`(8`+G?"?@@
M`R4@@`(X`(#^0`"`_D@`@/Y0`(#^6`"`_F``@/Y/_P`0:`"`_OI_19"4_J04
M6(*9W_M_1)"2_H,4)3```/Q_1)!(``,DC_Z#%"4H``#]?T.010`")(O^8A0H
M`+#?`@`&),;_!218@IG?2(">WPGX(`,E(``"((.9WR4H@`(E(``"*0`&)`GX
M(`,X.=YG2("+WR50@`)(@(??X&1I9B5`0`+P@)G?__\&)`$`!218:&ME)2`@
M`@GX(`,89^=D%OX`$/B"F=\)^"`#`````&#_O6<\`K?K`@`</$@`L/\T`*-G
M+>"9`R6`8``@`*/_^-:<9W(!L>OH@H+?J(*2WW\"ONOV`;7KM`&SZQB!F=\H
M`*+_``!$C@``0MPX`*+_"?@@`P`````!``,DL0!#H"4H``)(@(+?2("$WT@W
M660@981D9O<1!!@`N?\$`$`0,0`#)```1(#!`(,0`````)"`F=_X^A$$````
M`!B!F=\)^"`#``!$CDB`A=\+``<D,(*9WP$`!B0E($``"?@@`ZAGI61#`$`0
M&(&9WSB`D]\0`$/<D,-BC@(`0B@]`$`4*`!TW*B"@M\@`!4\)8@``#B`E]\!
M`!`D``2U)@`$%B0,```0$`"B_RB#F=\E(,`#"?@@`Q``Q=PJ`$`4D,-BC@$`
M$"8J&`(")@!@$`$`,288@9G?"?@@`P``1(YP@9G?)2B``B4X```E,"`""?@@
M`R4@0``:`$`0)2A`````1MSX&!``B,/BW@P`Q(P#&%[8)!"5`.3_5A`0`*+?
M&(&9WP@`I?\)^"`#``!$C`@`I=\"``<D<(*9WR4P```E($``"?@@`P``I=PH
M@YG?)2#``PGX(`,E*$``V?]`$)##8HZ0PV*.__]#)%\`<1`"`$(H&(&9WP``
M1(X)^"`#J(*1WTB`A=\#``<D,(*9WP$`!B0E($``"?@@`[!GI601`$`0)8!`
M`!B!F=\)^"`#```DCA```]Y(@(;?)2!``'B"F=\``&7<"?@@`[AGQF00``+>
M``!"W`P`0HR`!4)\I`!`%!B!F=\8@9G?``!$C@GX(`.H@I#?2("%WP,`!R0P
M@IG?`0`&)"4@0``)^"`#P&>E9!(`0!`EB$``2("$WQ@`N=\@`*7?"?@@`\AD
MA&0```2.)9A``&H`0!`8@9G?"?@@`P`````0`"/>)3!@`GB"F=\E($``"?@@
M`P``9=P8@9G?``!$C@GX(`,X@)/?2("$WR``I=\8`+G?N&2$9`GX(`.Q`$"@
M)8!``"\`0!"8PV+^T(&9W\`!!20)^"`#)2!``!$``R0$`$,0`0!#)`(`8RQ_
M`&`0)3A``"@`HM\X`*/?``!"W'<`8A1(`+#??P*^RSP"M\OV`;7+M`&SRW(!
ML<L(`.`#H`"]9Z+_0!08@9G?`0`0)``````8@9G?`0`0)@GX(`,``$2.X(*9
MWR4H@`()^"`#)2!``)##8HXJ$`("]?]`%!B!F=^3_P`0``!$C@$`0H!!_T`0
MD("9WSW_`!```````````#B`D-^8@)G?A_L1!(C#!-Y.`$`0F,-B_A``(MX@
M``,\``0%)``$8R0``$3<#`""C"000P`P`$44J(*"WQ``A-R(PQ#>B(*9WPGX
M(`,E*``"$``CW@`$!20EF$````!DW"```SP`!&,D#`""C"000P`5`$44```0
MWA``AMQ(@(3?)3A@`B4H``+H@9G?"?@@`_!GA&0`````"?@@`P`````X@(+?
M$``CWDB`F=^(PT+<``!DW(`^.6<Y^!$$``!%W)7_`!`8@9G?&(&9WPGX(`,`
M`$2.$``CWB4P``!P@IG?`@`')"4@0``)^"`#``!EW.+_`!`E,$``&(&9WPGX
M(`,``$2,$``CW@(`!R1P@IG?)2!``"4P```)^"`#``!EW,?_`!`E($``"?@@
M`P``)(X0``/>H(&9WR4@0``)^"`#``!EW%;_`!`8@9G?2("$W^B!F=\)^"`#
MR&>$9+B"F=\)^"`#`````#B`@M\E,``"2("$W^B!F=^(PT+<&&B$9`GX(`,`
M`$7<X/^]9W\`O.L"`!P\+>"9`\C1G&>@@)G?,0"PZW#Y$00EB(````!#@`@`
M8!`E@$```0!"9``````O`&0X``!#@`J`1`#\_V`4`0!"9("`F=]?^A$$````
M``P`0!``````"@`@$@```````"*"!P!`$"4@``)(@(7?,(.9WPGX(`.P9J5D
M!0`"$DB`F=]_`+S+,0"PRP@`X`,@`+UG)2`@`G\`O,LQ`+#+X#LY9S+W`!`@
M`+UG`````/#_O6<``+S_`@`</"W@F0,0T9QGP(""WPD`0!`(`+__8(*9WPGX
M(`,``$?<"`"_WP``O-\(`.`#$`"]9P````!@@IG?"?@@`R4X```(`+_?``"\
MWP@`X`,0`+UG`````,#_O6<P`+S_`@`</"W@F0.PT)QG$`"R_P``L/_(@)+?
MT("0W]B`F=\OD%`"*`"U_R``M/\8`+/_.`"__P@`L?_[D!(`)9B``"6@H`"T
M[A$$):C```H`0!(EB```````````&=XE,*`")2B``B4@8`()^"`#`0`Q9OG_
M,A8(`!!F.`"_WS``O-\H`+7?(`"TWQ@`L]\0`++?"`"QWP``L-\(`.`#0`"]
M9P@`X`,`````$("9WR5XX`,)^"`#;``89!"`F=\E>.`#"?@@`VL`&&00@)G?
M)7C@`PGX(`-J`!AD$("9WR5XX`,)^"`#:``89!"`F=\E>.`#"?@@`V8`&&00
M@)G?)7C@`PGX(`-E`!AD$("9WR5XX`,)^"`#9``89!"`F=\E>.`#"?@@`V(`
M&&00@)G?)7C@`PGX(`-@`!AD$("9WR5XX`,)^"`#7P`89!"`F=\E>.`#"?@@
M`UX`&&00@)G?)7C@`PGX(`-=`!AD$("9WR5XX`,)^"`#7``89!"`F=\E>.`#
M"?@@`UH`&&00@)G?)7C@`PGX(`-9`!AD$("9WR5XX`,)^"`#5P`89!"`F=\E
M>.`#"?@@`U8`&&00@)G?)7C@`PGX(`-5`!AD$("9WR5XX`,)^"`#5``89!"`
MF=\E>.`#"?@@`U,`&&00@)G?)7C@`PGX(`-2`!AD$("9WR5XX`,)^"`#40`8
M9!"`F=\E>.`#"?@@`U``&&00@)G?)7C@`PGX(`-/`!AD$("9WR5XX`,)^"`#
M3@`89!"`F=\E>.`#"?@@`TT`&&00@)G?)7C@`PGX(`-,`!AD$("9WR5XX`,)
M^"`#2P`89!"`F=\E>.`#"?@@`TD`&&00@)G?)7C@`PGX(`-(`!AD$("9WR5X
MX`,)^"`#1P`89!"`F=\E>.`#"?@@`T8`&&00@)G?)7C@`PGX(`-%`!AD$("9
MWR5XX`,)^"`#1``89!"`F=\E>.`#"?@@`T,`&&00@)G?)7C@`PGX(`-"`!AD
M$("9WR5XX`,)^"`#00`89!"`F=\E>.`#"?@@`T``&&00@)G?)7C@`PGX(`,_
M`!AD$("9WR5XX`,)^"`#/0`89!"`F=\E>.`#"?@@`SP`&&00@)G?)7C@`PGX
M(`,[`!AD$("9WR5XX`,)^"`#.@`89!"`F=\E>.`#"?@@`SD`&&00@)G?)7C@
M`PGX(`,X`!AD$("9WR5XX`,)^"`#-P`89!"`F=\E>.`#"?@@`S8`&&00@)G?
M)7C@`PGX(`,U`!AD$("9WR5XX`,)^"`#-``89!"`F=\E>.`#"?@@`S$`&&00
M@)G?)7C@`PGX(`,P`!AD$("9WR5XX`,)^"`#+P`89!"`F=\E>.`#"?@@`RX`
M&&00@)G?)7C@`PGX(`,L`!AD$("9WR5XX`,)^"`#*@`89!"`F=\E>.`#"?@@
M`RD`&&00@)G?)7C@`PGX(`,H`!AD$("9WR5XX`,)^"`#)P`89!"`F=\E>.`#
M"?@@`R8`&&00@)G?)7C@`PGX(`,E`!AD$("9WR5XX`,)^"`#)``89```````
M``````````````#P_[UG``"\_P(`'#PMX)D#"`"__R#,G&<(`+_?``"\WP@`
MX`,0`+UG```````````!``(``````"5S+R5S````+W!R;V,O<V5L9B]E>&4`
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI0
M05(Z.D)/3U0`````97AE```````O<')O8R\E:2\E<P``````+@````````!0
M05)?5$5-4```````````4$%27U!23T=.04U%`````#H`````````+P``````
M```E<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4````
M``````!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````
M4$%27T-,14%.`````````%!!4E]$14)51P````````!005)?0T%#2$4`````
M````4$%27T%21T,``````````%!!4E]!4D=67S````````!005)?1TQ/0D%,
M7T1%0E5'``````````!005)?1TQ/0D%,7U1-4$1)4@````````!005)?5$U0
M1$E2````````4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````
M`````%!!4E]#3$5!3CT````````Q`````````$Q)0E!!5$@`3$1?3$E"4D%2
M65]0051(`$Q)0E)!4EE?4$%42`````!$64Q$7TQ)0E)!4EE?4$%42```````
M``!32$Q)0E]0051(````````55-%4@````!365-414T``"]T;7``````5$U0
M1$E2``!414U01$E2`%1%35``````5$U0``````!54T523D%-10``````````
M)3`R>`````!P87(M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M````````<&%R;``````N<&%R`````"5S)7-C86-H92TE<R5S```E<R5S=&5M
M<"TE=25S````)7,E<W1E;7`M)74M)74E<P``````````)7,Z('!R:79A=&4@
M<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V92!I="!A
M;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````$%21U8`````&```````
M``!P97)L`````#``````````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E
M8W1O<GD``````````"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N
M;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E
M8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90```````"TM
M````````979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`
M(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@<V]M92!S:&5L;`IP86-K
M86=E(%]?<&%R7W!L.PIM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F
M:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I
M;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL
M93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1P87)?=&5M<"D["F]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?
M=&5M<")]*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_
M(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M
M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY
M("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8
M)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3
M549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B
M(R$O8FEN+W-H"G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR
M9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*
M8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@
M+B`D=&UP+3YF:6QE;F%M92`N("(G"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL
M96YA;64["FUY("1C;60@/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L
M;"`R/B8Q("8G.PIC;&]S92`D=&UP.PIS>7-T96TH)&-M9"D["F]U=',H<7$H
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`I"BX@)'1M<"T^9FEL96YA;64I.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/
M3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FEF("AE>&ES=',@)$5.5GM0
M05)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I('L*0$%21U8@/2!M
M87`@)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@
M+2`Q*3L*)#`@/2`D14Y6>U!!4E]!4D=67S!].PI]"F5L<V4@>PIF;W(@*&ME
M>7,@)45.5BD@>PID96QE=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PI]
M"GT*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]
M("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z
M)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG
M=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@
M+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H
M*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S
M*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L
M("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U
M9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3([
M"FUY("1I9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF
M("1O9F9S970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I
M92!Q<5MS965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E
M860@/2!R96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I
M;&5D(&]N("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F
M<V5T.PHD:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@
M:68@)&ED>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^
M(#$R."`J(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X
M(#X](#`["B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E
M="P@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M
M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A
M=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN
M*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C
M<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B
M=68["F-L;W-E("1O=70["F-H;6]D(#`W-34L("1F:6QE;F%M93L*?0HD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`]("(D14Y6>U!!
M4E]414U0?2\D8F%S96YA;64D97AT(CL*;W5T<R@B4TA,24(Z("1F:6QE;F%M
M95QN(BD["F]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A
M.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70[
M"GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*
M8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE+`I].PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U
M;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H:V5Y<R`E<F5Q=6ER95]L
M:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<120O.PHD:V5Y(#T@)%\[
M(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[)&ME>7T@:68@9&5F:6YE
M9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO9'5L97T@/2`B+VQO861E
M<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD
M(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE
M+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<')I;G0@
M)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H+"`P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G
M+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D;W5T*2!["F)I;FUO9&4H
M)&]U="D["G!R:6YT("1O=70@)&9I;&5N86UE+3Y[8G5F?3L*8VQO<V4@)&]U
M=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I
M;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I
M970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O
M<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@
M>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T
M86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E
M<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S
M92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF
M="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@
M0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH
M6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG
M*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I
M('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI
M9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@
M/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<[
M"GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS
M:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G
M3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN
M;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H
M95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D
M:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?
M:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O
M<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,[
M"GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z
M:7`["FEF("AD969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H,3(X*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I
M92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R
M;W(Z("0A(CL*?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE
M=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S
M+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^
M("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE
M("(D(3H@)'!A<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A
M(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R
M96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T
M+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@
M?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN
M;6]D92@D9F@I.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?
M<&]S(#H@=6YD968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A
M;&%R(#Q?1D@^.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E
M<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<
M)&QO861E<BP@)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N
M=BD@>PIM>2`D=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A
M;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y6
M7U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@
M=6,H)&ME>2D@+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U[
M"B1M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H
M)'-E="DI*0I]96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E
M9CL*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?
M;6]D=6QE<R@I.PIM>2!`:6YC(#T@<V]R="!["FQE;F=T:"@D8BD@/#T^(&QE
M;F=T:"@D82D*?2!G<F5P('L*(2]"4T1004XO"GT@9W)E<"!["B@D8G5N9&QE
M(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB
M97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*
M?2!`24Y#.PIM>2`E9FEL97,["B]>7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D
M9FEL97-[)#%]*RL@9F]R(&ME>7,@)3HZ.PHD9FEL97-[)%]]*RL@9F]R('9A
M;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?
M97AT?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I
M('L*;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@
M>PII9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD
M9FEL92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#
M8UTI*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*
M?0IE;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@
M*&UY("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@
M(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I
M.PIL87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N
M;W0@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD
M("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ
M<2A086-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I
M;&4L"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@
M>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%
M+"`G/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB
M:6YM;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@
M)&9I;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<
M+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ
M<2A7<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M
M/G!R:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT
M*3L*?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*
M)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H
M(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI
M('L*;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E
M<W0Z.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI3
M2$$Q.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO
M;B`](&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H
M)'-H85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N
M,SDG*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*
M96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*
M8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D[
M"GT*?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D
M;71I;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I
M;G0H)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E
M;&P@+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<
M;B(I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*
M;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE
M*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII
M<#L*?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R
M(&1I92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D
M(3H@)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#
M86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-
M4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H
M;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$[
M"FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%2
M7U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@
M+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ
M<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R
M86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U
M-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL
M97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P
M(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B
M($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ
M0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z
M.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER
M92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S
M<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R
M97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A
M9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E
M('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER
M92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E
M<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE
M.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2
M.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T[
M"F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA
M<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R
M<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@
M?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A
M;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?
M=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!
M4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*
M?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]4
M35!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-
M4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@
M+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I
M9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D
M/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E
M<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D
M<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA
M;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG
M.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A
M=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE
M*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y]
M(&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N
M("AM>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*
M<WES<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%
M(BD@>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$[
M"B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E
M=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W
M('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U
M+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(
M03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D
M<')O9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A
M;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I
M.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92![
M"B1%3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D
M96QI;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM
M:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I
M9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO
M.PI]"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@
M*"1F:"P@)&9I;&5N86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C
M)&5X="(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M
M92!I9B`M92`D9FEL96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*
M?0IE;'-E('L*<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I
M;&5N86UE*3L*?0IO<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A
M.PIB:6YM;V1E*"1F:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%2
M7U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM
M?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG
M>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)$-O;F9I9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I
M"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?
M97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M
M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE
M+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#
M=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS
M,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H
M)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L
M:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-
M17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%
M3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E
M('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=6
M7S`@*2`I('L*9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!4
M35!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]
M("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%
M04Y?7R`@("`@("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID
M96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[
M4$%27T=,3T)!3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?
M8VQE86XL(#$R("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y]
M(#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U
M8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN
M="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS
M=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P
M(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI
M8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R
M87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I
M<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI
M;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P
M97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C
M=&]R>5QN*0IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/
M4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/
M4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<
M9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%
M3D1?7PH``````````````````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@
M("`@("`@``````````!P97)L>'-I+F,````````````````````O;&EB-C0O
M;&0N<V\N,0````````0````0`````0```$=.50```````@````8````@````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````"X'@`@`0```&@>`"`!
M````````````````````````````````````_____P```````````````'!H
M`"`!````````````````````````````````````````````````````````
M@.`:`"`!````@%\`(`$````H8``@`0```````B`!````.+`!(`$````````@
M`0```````2`!````L#\`(`$````X60`@`0```'A``"`!````X$@`(`$```"0
M00`@`0```#A(`"`!````,$D`(`$```"P10`@`0````A+`"`!````2$0`(`$`
M```@7P`@`0```""P`2`!````:%X`(`$```!HLP$@`0```/"O`2`!````Z*\!
M(`$```"@&@`@`0````````````````````````#P8P`@`0```.!C`"`!````
MT&,`(`$```#`8P`@`0```+!C`"`!````H&,`(`$```"08P`@`0``````````
M````@&,`(`$``````````````'!C`"`!````8&,`(`$```!08P`@`0```$!C
M`"`!`````````````````````````#!C`"`!````(&,`(`$````08P`@`0``
M``!C`"`!````\&(`(`$```#@8@`@`0```-!B`"`!````P&(`(`$```"P8@`@
M`0```*!B`"`!``````````````"08@`@`0```(!B`"`!````<&(`(`$```!@
M8@`@`0```%!B`"`!````0&(`(`$````P8@`@`0```"!B`"`!````$&(`(`$`
M````8@`@`0```/!A`"`!``````````````#@80`@`0```-!A`"`!````P&$`
M(`$```"P80`@`0```*!A`"`!````D&$`(`$```"`80`@`0```'!A`"`!````
M8&$`(`$```!080`@`0```$!A`"`!````,&$`(`$````@80`@`0``````````
M````$&$`(`$`````80`@`0``````````````\&``(`$```#@8``@`0```-!@
M`"`!````P&``(`$```"P8``@`0``````````````H&``(`$`````````````
M`)!@`"`!````@&``(`$```!P8``@`0``````````````8&``(`$`````````
M`````%!@`"`!````0&``(`$````P8``@`0``````````````1T-#.B`H56)U
M;G1U(#4N-"XP+39K;W)D,7XQ-BXP-"XT:S(I(#4N-"XP(#(P,38P-C`Y`!`?
M`"```#^0^/___P``````````T`(``!T````?````2#<`(```?Y#X____````
M``````!0````'0```!\```!P.``@```?D/C___\``````````%`````=````
M'P```#@Y`"```'^0^/___P``````````8````!T````?````X#L`(```_]#X
M____``````````!``0``'0```!\```#`/0`@```#D/C___\``````````"``
M```=````'P```(`^`"```!^0^/___P``````````4!```!T````?````L#\`
M(````)#X____```````````0````'0```!\`````0``@```!D/C___\`````
M`````"`````=````'P```'A``"````>0^/___P``````````8"```!T````?
M````>$$`(```````````````````````````'0```!\```"000`@``#_T/C_
M__\``````````(`0```=````'P```!A$`"``````````````````````````
M`!T````?````2$0`(````Y#X____```````````@````'0```!\```"P10`@
M``#_D/C___\``````````)`````=````'P```#A(`"````.0^/___P``````
M````,````!T````?````X$@`(````)#X____```````````0````'0```!\`
M```P20`@``#_T/C___\``````````-`````=````'P````A+`"```/_0^/__
M_P``````````\($``!T````?````.%D`(```_]#X____``````````"@````
M'0```!\```!H7@`@```#D/C___\``````````"`````=````'P```.`:`"``
M`#^0^/___P``````````<````!T````?````(%\`(````)#X____````````
M```0````'0```!\```"`7P`@```_D/C___\``````````$`````=````'P``
M`"A@`"```````````````````````````!T````?````00\```!G;G4``0<`
M```$`0`N<VAS=')T86(`+DU)4%,N86)I9FQA9W,`+DU)4%,N;W!T:6]N<P`N
M;F]T92YG;G4N8G5I;&0M:60`+F1Y;F%M:6,`+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N:6YI=``N=&5X=``N
M34E04RYS='5B<P`N9FEN:0`N<F]D871A`"YI;G1E<G``+F5H7V9R86UE`"YN
M;W1E+D%"22UT86<`+FEN:71?87)R87D`+F9I;FE?87)R87D`+FIC<@`N9&%T
M80`N<FQD7VUA<``N9V]T`"YS9&%T80`N8G-S`"YC;VUM96YT`"YP9'(`+F=N
M=2YA='1R:6)U=&5S````````````````````````````````````````````
M``````````````````````````````````````````````````L````J``!P
M`@````````!P`@`@`0```'`"````````&`````````````````````@`````
M````&``````````:````#0``<`(```@`````B`(`(`$```"(`@```````)`!
M```````````````````(``````````$`````````*`````<````"````````
M`!@$`"`!````&`0````````D````````````````````!```````````````
M`````#L````&`````@````````!`!``@`0```$`$````````,`(````````'
M``````````@`````````$`````````!$````!0````(`````````<`8`(`$`
M``!P!@```````$`#````````!@`````````(``````````0`````````2@``
M``L````"`````````+`)`"`!````L`D````````X"@````````<````!````
M"``````````8`````````%(````#`````@````````#H$P`@`0```.@3````
M````+`4```````````````````$```````````````````!:````____;P(`
M````````%!D`(`$````4&0```````-H`````````!@`````````"````````
M``(`````````9P```/[__V\"`````````/`9`"`!````\!D```````"P````
M``````<````#````"````````````````````'8````!````!@````````"@
M&@`@`0```*`:````````0`````````````````````0`````````````````
M``!\`````0````8`````````X!H`(`$```#@&@```````%!%````````````
M```````0````````````````````@@````$````&`````````#!@`"`!````
M,&````````#@`P``````````````````"````````````````````(X````!
M````!@`````````09``@`0```!!D````````*`````````````````````0`
M``````````````````"4`````0````(`````````0&0`(`$```!`9```````
M`#!"```````````````````0````````````````````G`````$````"````
M`````'"F`"`!````<*8````````/`````````````````````0``````````
M`````````*0````!`````@````````"`I@`@`0```("F````````!```````
M``````````````0```````````````````"N````!P````(`````````A*8`
M(`$```"$I@```````"`````````````````````$````````````````````
MO`````X````#`````````.BO`2`!````Z*\````````(````````````````
M````"````````````````````,@````/`````P````````#PKP$@`0```/"O
M````````"`````````````````````@```````````````````#4`````0``
M``,`````````^*\!(`$```#XKP````````@````````````````````(````
M````````````````V0````$````#``````````"P`2`!`````+`````````P
M````````````````````$````````````````````-\````!`````P``````
M```PL`$@`0```#"P````````"`````````````````````@`````````````
M``````#H`````0````,``!``````0+`!(`$```!`L````````"@#````````
M```````````0``````````@`````````[0````$````#```0`````&BS`2`!
M````:+,````````(````````````````````"````````````````````/0`
M```(`````P````````!PLP$@`0```'"S````````0!``````````````````
M`!````````````````````#Y`````0```#````````````````````!PLP``
M`````#0````````````````````!``````````$``````````@$```$`````
M````````````````````I+,````````@`P``````````````````!```````
M``````````````<!``#U__]O`````````````````````,2V````````$```
M``````````````````$````````````````````!`````P``````````````
M``````````#4M@```````!<!```````````````````!````````````````
#````
